@@ -2,7 +2,7 @@ import os
 import yaml
 import logging
 import subprocess
-from jinja2 import Environment, PackageLoader, select_autoescape
+from jinja2 import Environment, PackageLoader
 from hedera import Client, AccountId, PrivateKey, Hbar, FileCreateTransaction, FileContentsQuery, FileId, FileAppendTransaction, FileInfoQuery
 
 OPERATOR_ID= AccountId.fromString(os.environ["OPERATOR_ID"])
@@ -41,10 +41,10 @@ class network3_perseus():
 
     def push_config(self,yaml_contents):
         env = Environment(loader=PackageLoader("network3_perseus", "templates"))
-        autoescape=select_autoescape()
         intended_config_template = env.get_template('intended_config.j2')
         rendered_intended_config = intended_config_template.render(self.yaml_contents)
-        subprocess.run(["python", "cli_configure.py", rendered_intended_config])
+        configure_output=subprocess.run(["python", "cli_configure.py", rendered_intended_config.replace("\n","")], capture_output=True)
+        print(configure_output)
 
     def add_file_to_hedera(self, raw_json):
         self.client = Client.forTestnet()
